ENV_PROJECT_ID='MONITORING_DEPLOY_PROJECT_ID'
ENV_DEPLOY_ID='MONITORING_DEPLOY_DEPLOY_ID'

BACK_END_API_URI = 'ENV_BACK_END_API_URI'
BACK_END_API_URL = 'ENV_BACK_END_API_URL'
BACK_END_API_PORT = 'ENV_BACK_END_API_PORT'
